Welcome to MiniPyP
==================
.. note::

   This documentation is a work in progress, but contains (hopefully) everything you need to get started.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   quickstart
   configuration
   dynamic-content
   useful-methods



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
